@@ -3,9 +3,9 @@ use strict;
 use warnings;
 use base qw{Path::Class::File};
 use File::Tempdir qw{};
-use Archive::Zip qw(AZ_OK); #TODO use Archive::Extract instead
+use Archive::Extract qw{};
 
-our $VERSION = '0.05';
+our $VERSION = '0.08';
 
 =head1 NAME
 
@@ -30,27 +30,24 @@ Net::SFTP::Foreign::Tempdir::Extract::File is a convince wrapper around L<Path::
 
 Extracts Zip files to temporary directory
 
-  my @files = $archive->extract; #array of Net::SFTP::Foreign::Tempdir::Extract::File files
+  my @files = $archive->extract; #list of Net::SFTP::Foreign::Tempdir::Extract::File files
   my $files = $archive->extract; #array reference of Net::SFTP::Foreign::Tempdir::Extract::File files
 
-Note: The file is temporary and will be cleaned up when the variable goes out of scope.
+Note: These files are temporary and will be cleaned up when the variable goes out of scope.
 
 =cut
 
 sub extract {
   my $self = shift;
-  my $az   = Archive::Zip->new;
-  unless ($az->read($self->stringify) == AZ_OK) {die(qq{Error: Cannot open file "$self".})};
-  my @files=();
-  foreach my $member ($az->members) {
-    next if $member->isDirectory;
-    my $tmpdir          = File::Tempdir->new;                 #separate tmp directory for each file for fine grained cleanup
-    my $local_folder    = $tmpdir->name;
-    my $name            = $member->fileName;
-    my $file            = $self->new($local_folder, $name);   #isa Net::SFTP::Foreign::Tempdir::Extract::File (not -f yet)
+  my $ae     = Archive::Extract->new(archive=>"$self");
+  my $ae_dir = File::Tempdir->new;
+  $ae->extract(to=>$ae_dir->name) or die $ae->error;
+  my @files  = ();
+  foreach my $filename ($ae->files) {
+    my $tmpdir  = File::Tempdir->new;                         #separate tmp directory for each file for fine grained cleanup
+    my $file     = $self->new($filename);                     #isa Path::Class::File object
+    $file->move_to($tmpdir->name) or die("Error: Failed to move file to temp directory");
     $file->{"__tmpdir"} = $tmpdir;                            #needed for scope clean up of File::Tempdir object
-    my $status          = $az->extractMember($name, $file->stringify); #automatically creates directory structure
-    die("Error: Failed to extract file $name.") unless $status == AZ_OK;
     die("Error: File $file is not readable.") unless -r $file;
     push @files, $file;
   }
